@@ -57,9 +57,12 @@ class TitleText(widget.Widget):
                 self._passon['width'] -= self.text_field_begin_at+1
         
         if self.use_two_lines:
-            if 'max_height' in self._passon:
+            if 'max_height' in self._passon and self._passon['max_height']:
+                if self._passon['max_height'] == 1:
+                    raise ValueError("I don't know how to resolve this: max_height == 1 but widget using 2 lines.")
                 self._passon['max_height'] -= 1
-            if 'height' in self._passon:
+            if 'height' in self._passon and self._passon['height']:
+                raise ValueError("I don't know how to resolve this: height == 1 but widget using 2 lines.")
                 self._passon['height'] -= 1
         
 
@@ -140,6 +143,21 @@ class TitleText(widget.Widget):
     def del_value(self):
         del self.entry_widget.value
     value = property(get_value, set_value, del_value)
+    
+    @property
+    def editable(self):
+        try:
+            return self.entry_widget.editable
+        except AttributeError:
+            return self._editable
+        
+    @editable.setter
+    def editable(self, value):
+        self._editable = value
+        try:
+            self.entry_widget.editable = value
+        except AttributeError:
+            self._editable = value
 
 
 class TitleFixedText(TitleText):
